package com.example.smartlab.Activity

import android.content.Intent
import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.os.CountDownTimer
import android.util.Log
import android.view.View
import android.view.inputmethod.EditorInfo
import android.widget.Toast
import com.example.smartlab.Api.ApiRequest
import com.example.smartlab.Api.sendCodeToEmail
import com.example.smartlab.GlobalSharedPreferences
import com.example.smartlab.databinding.ActivityCodeFromEmailBinding
import com.google.gson.GsonBuilder
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.async
import kotlinx.coroutines.launch
import okhttp3.OkHttpClient
import okhttp3.logging.HttpLoggingInterceptor
import retrofit2.Retrofit
import retrofit2.awaitResponse
import retrofit2.converter.gson.GsonConverterFactory
import retrofit2.converter.scalars.ScalarsConverterFactory

class CodeFromEmail : AppCompatActivity() {
    private  lateinit var shPref: GlobalSharedPreferences

    private lateinit var binding: ActivityCodeFromEmailBinding
    private lateinit var _email:String
    private var codeResult: Int? = null
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityCodeFromEmailBinding.inflate(layoutInflater)
        setContentView(binding.root)
        shPref = GlobalSharedPreferences(this)
        //получение значения почты
        _email = intent.getStringExtra("Email").toString()
        //для обработки нажатия enter в editText
        binding.editLastNumeric.setOnEditorActionListener { v, actionId, event ->
            if (actionId == EditorInfo.IME_ACTION_DONE) {
                checkCode()
                true
            } else {
                false
            }
        }
        listener()
        countdownForResending()
    }

    private fun listener() {
        binding.btnPreview.setOnClickListener() {
            finish()
        }
        binding.btnSendCodeAgain.setOnClickListener() {
            binding.btnSendCodeAgain.isEnabled = false
            binding.btnSendCodeAgain.visibility = View.INVISIBLE
            sendCodeToEmail(_email)
            countdownForResending()
            //этобыла попытка в обработку ответа от api, но что-то пошло не так
//            if(sendCodeToEmail(intent.getStringExtra("Email").toString()))
//            {
//                countdownForResending()
//            }
//            else
//            {
//                Toast.makeText(this, "Что-то пошло не так при отправке сообщения на почту! Проверьте подключение к интернету и попробуйте еще раз.", Toast.LENGTH_LONG).show()
//            }
        }
    }

    private fun countdownForResending() {
        object : CountDownTimer(60000, 1000) {

            override fun onTick(millisUntilFinished: Long) {
                binding.descriptionAboutNextSend.text =
                    "Отправить код повторно можно будет через " + millisUntilFinished / 1000 + " секунд"
            }

            // Когда таймер истек
            override fun onFinish() {
                binding.descriptionAboutNextSend.text = ""
                binding.btnSendCodeAgain.isEnabled = true
                binding.btnSendCodeAgain.visibility = View.VISIBLE
            }
        }.start()
    }

    private fun checkCode() {
        var code = binding.edit1Numeric.text.toString() + binding.edit2Numeric.text.toString() + binding.edit3Numeric.text.toString() + binding.editLastNumeric.text.toString()
        if (code.length == 4) {
            signInFromCode(code)
            if(codeResult == 200){
                startActivity(Intent(this, CreatePasswordActivity::class.java))
                finish()
            } else if (codeResult != null && codeResult != 1)  {
                Toast.makeText(this, "Неверный код", Toast.LENGTH_LONG).show()
            }
//            else{
//                Toast.makeText(this, ".", Toast.LENGTH_LONG).show()
//            }

            }
        }
    private fun signInFromCode(code: String) {

        val interceptor = HttpLoggingInterceptor()
        interceptor.level = HttpLoggingInterceptor.Level.BODY

        val httpClient = OkHttpClient.Builder()
            .addInterceptor(interceptor)
            .build()

        val gsonBuilder = GsonBuilder()
            .setLenient()
            .create()

        val retrofit = Retrofit.Builder()
            .addConverterFactory(ScalarsConverterFactory.create())
            .addConverterFactory(GsonConverterFactory.create(gsonBuilder))
            .baseUrl("https://iis.ngknn.ru/NGKNN/МамшеваЮС/MedicMadlab/")
            .client(httpClient)
            .build()

        val requestApi = retrofit.create(ApiRequest::class.java)
        CoroutineScope(Dispatchers.IO).launch {
            codeResult = try {
//                val response = requestApi.postSignIn(_email, code).execute()
                val response = async { requestApi.postSignIn(_email, code) }.await().awaitResponse()
                if (response.isSuccessful){
                    var data:String = response.body()!!
                    shPref.token = data
                    Log.d("ResponseSendCode", data.toString())
                } else{
                    Log.d("ResponseSendCodeErr", response.errorBody().toString())
                }
                response.code()
            } catch (e: Exception) {
                Log.d("ResponseSendCodeErr", e.toString())
                1
            }
        }
    }
}





