package com.example.smartlab.Fragment

import android.app.Activity
import android.os.Build
import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Toast
import androidx.annotation.RequiresApi
import androidx.fragment.app.Fragment
import androidx.fragment.app.FragmentActivity
import androidx.recyclerview.widget.LinearLayoutManager
import com.example.smartlab.Adapter.AdapterNews
import com.example.smartlab.Adapter.CatalogAdapter
import com.example.smartlab.Adapter.CategoryAdapter
import com.example.smartlab.Api.ApiRequest
import com.example.smartlab.CatalogDialogFragment
import com.example.smartlab.Model.Catalog
import com.example.smartlab.Model.News
import com.example.smartlab.databinding.FragmentAnalyzesBinding
import com.example.smartlab.databinding.ItemFilterAnalyzeBinding
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import retrofit2.Retrofit
import retrofit2.awaitResponse
import retrofit2.converter.gson.GsonConverterFactory


@Suppress("DEPRECATION")
class AnalyzesFragment : Fragment(), CategoryAdapter.Listener, CatalogAdapter.Listener {

    private var _binding: FragmentAnalyzesBinding? = null
    private val binding get() = _binding!!
    //для списка категорий
    private val listCategory = listOf("Популярные", "COVID", "Онкогенетические", "ЗОЖ").toMutableList()
    private val selectedCategory = listCategory[0]
    private val categoryAdapter = CategoryAdapter(this, selectedCategory)
    //для списка новостей
    private val newsAdapter = AdapterNews()
    //для списка анализов
    private val catalogAdapter = CatalogAdapter(this)


    companion object {
        fun newInstance() = AnalyzesFragment()
    }


    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        _binding = FragmentAnalyzesBinding.inflate(inflater, container, false)

        getData()

        return binding.root
    }

    private fun getData(){
        val requestApi = Retrofit.Builder()
            .baseUrl("https://iis.ngknn.ru/NGKNN/МамшеваЮС/MedicMadlab/")
            .addConverterFactory(GsonConverterFactory.create())
            .build()
            .create(ApiRequest::class.java)
        CoroutineScope(Dispatchers.IO).launch {
            try{
                val response = requestApi.getNews().awaitResponse()
                if(response.isSuccessful){
                    val news = response.body()!!
                    this@AnalyzesFragment.activity?.runOnUiThread{ initListNews(news)}
                    Log.d("ResponseGetNews", news.toString())
                }
                else{
                    Log.d("ResponseGetNewsErr", response.errorBody().toString())
                }
            }
            catch (e: Exception) {
                Log.d("ResponseGetNewsErr", e.toString())
            }
        }
        CoroutineScope(Dispatchers.IO).launch {
            try{
                val response = requestApi.getCatalog().awaitResponse()
                if(response.isSuccessful){
                    val catalog = response.body()!!
                    this@AnalyzesFragment.activity?.runOnUiThread{ initListCatalog(catalog)}
                    Log.d("ResponseGetCatalog", catalog.toString())
                }
                else{
                    Log.d("ResponseGetCatalogErr", response.errorBody().toString())
                }
            }
            catch (e: Exception) {
                Log.d("ResponseGetCatalogErr", e.toString())
            }
        }
    }
    private fun initCategoryList(){
        //Настройка категорий
        val categoryManager = LinearLayoutManager(this.requireContext(), LinearLayoutManager.HORIZONTAL, false)
        categoryAdapter.data = listCategory
        binding.listCategoryAnalyses.layoutManager = categoryManager
        binding.listCategoryAnalyses.adapter = categoryAdapter

    }
    private fun initListNews(news: List<News>){
        //Настройка новостей
        val newsManager = LinearLayoutManager(this.requireContext(), LinearLayoutManager.HORIZONTAL, false)
        newsAdapter.newsList = news
        with(binding){
            listNews.layoutManager = newsManager
            listNews.adapter = newsAdapter
        }
    }
    private fun initListCatalog(catalog: List<Catalog>){
        //Настройка новостей
        val catalogManager = LinearLayoutManager(this.requireContext())
        catalogAdapter.data = catalog
        with(binding){
            listCatalogAnalyses.layoutManager = catalogManager
            listCatalogAnalyses.adapter = catalogAdapter
        }
    }

    @RequiresApi(Build.VERSION_CODES.O)
    override fun OnClickCategory(category: View) {
        val bindingCategory = ItemFilterAnalyzeBinding.bind(category)
        bindingCategory.btnCategory.focusable = View.FOCUSABLE
        bindingCategory.btnCategory.isFocusableInTouchMode = true
//        bindingCategory.btnCategory.requestFocus()
    }

    override fun OnChecked(catalog: Catalog) {
        Toast.makeText(this.requireContext(),"On для элемента", Toast.LENGTH_LONG).show()
    }

    override fun OffChecked(catalog: Catalog) {
        Toast.makeText(this.requireContext(),"Off для элемента", Toast.LENGTH_LONG).show()
    }

    @Suppress("DEPRECATION")
    override fun OnClickCatalog(catalog: Catalog) {
        Toast.makeText(this.requireContext(),"Элементик нажали"+catalog.name.toString(), Toast.LENGTH_LONG).show()
        val fragment = CatalogDialogFragment()
        val bundle = Bundle()
        bundle.putSerializable("itemcatalog", catalog)
        fragment.arguments = bundle
       /* val activity = (this.requireContext() as Activity)
        var sfm = activity.fragmentManager!!*/
        fragment.show((this.requireContext() as FragmentActivity).supportFragmentManager, "pop")
    }


}